def calcular_frequencia_respiratoria(fr, idade):
    """
    Calcula a frequência respiratória e determina em qual categoria se enquadra.

    Attributes:
        fr (int): Frequência respiratória (número de respirações por minuto).
        idade (int): Idade do indivíduo.

    Returns:
        str: Categoria da frequência respiratória, que pode ser:
            - 'muito baixa': se a frequência respiratória estiver significativamente abaixo da média para a idade,
            - 'baixa': se a frequência respiratória estiver abaixo da média para a idade,
            - 'normal': se a frequência respiratória estiver dentro da faixa considerada normal para a idade,
            - 'alta': se a frequência respiratória estiver acima da média para a idade,
            - 'muito alta': se a frequência respiratória estiver significativamente acima da média para a idade.
    """
    if idade < 1:
        if 30 <= fr <= 60:
            return "normal"
        elif fr < 30:
            return "muito baixa"
        else:
            return "muito alta"
    elif 1 <= idade <= 5:
        if 20 <= fr <= 30:
            return "normal"
        elif fr < 20:
            return "muito baixa"
        else:
            return "muito alta"
    elif 6 <= idade <= 12:
        if 15 <= fr <= 25:
            return "normal"
        elif fr < 15:
            return "muito baixa"
        else:
            return "muito alta"
    elif idade > 12:
        if 12 <= fr <= 20:
            return "normal"
        elif fr < 12:
            return "muito baixa"
        else:
            return "muito alta"





def analisar_status(valor, referencia):
    """
    Analisa o status de um valor em relação a uma faixa de referência.

    Attributes:
        valor (float): O valor a ser analisado.
        referencia (list): A faixa de referência na forma [min, max].

    Returns:
        str: O status do valor em relação à faixa de referência.
    """

    if valor < referencia[0]:
        return "Muito baixo"
    elif referencia[0] <= valor <= referencia[1]:
        return "Baixo"
    elif referencia[1] < valor <= referencia[2]:
        return "Normal"
    elif referencia[2] < valor <= referencia[3]:
        return "Alto"
    else:
        return "Muito alto"

def teste_funcao_tireoidiana(tsh, t4_total, t4_livre, t3_total, t3_livre, saida='advanced'):
    """
    Avalia a função da tireoide medindo os níveis de hormônios tireoidianos no sangue.

    Attributes:
        tsh (float): Valor do hormônio estimulante da tireoide (TSH) em mIU/L.
        t4_total (float): Valor do hormônio tiroxina total (T4 Total) em nmol/L.
        t4_livre (float): Valor do hormônio tiroxina livre (T4 Livre) em ng/dL.
        t3_total (float): Valor do hormônio tri-iodotironina total (T3 Total) em nmol/L.
        t3_livre (float): Valor do hormônio tri-iodotironina livre (T3 Livre) em pg/mL.
        saida (str): Tipo de saída desejado ('advanced' ou 'simple').

    Returns:
        str or tuple: Resultado do teste de função tireoidiana. Se 'saida' for 'simple', retorna apenas o resultado. Se 'saida' for 'advanced', retorna o resultado detalhado.
    """

    referencia_tsh = [0.3, 4.0, 10.0, 20.0]
    referencia_t4_total = [60, 160, 200, 350]
    referencia_t4_livre = [0.8, 1.8, 2.5, 3.9]
    referencia_t3_total = [0.6, 2.0, 2.5, 5.7]
    referencia_t3_livre = [2.0, 4.4, 5.4, 8.7]

    if saida == 'simple':
        status_tsh = analisar_status(tsh, referencia_tsh)
        status_t4_total = analisar_status(t4_total, referencia_t4_total)
        status_t4_livre = analisar_status(t4_livre, referencia_t4_livre)
        status_t3_total = analisar_status(t3_total, referencia_t3_total)
        status_t3_livre = analisar_status(t3_livre, referencia_t3_livre)

        return f"TSH: {tsh} - Classificação: {status_tsh}\n" \
               f"T4 Total: {t4_total} - Classificação: {status_t4_total}\n" \
               f"T4 Livre: {t4_livre} - Classificação: {status_t4_livre}\n" \
               f"T3 Total: {t3_total} - Classificação: {status_t3_total}\n" \
               f"T3 Livre: {t3_livre} - Classificação: {status_t3_livre}"
    else:
        pass



def classificar_espirometria(fe_v1, cvf, sexo, idade):
    """
    Analisa os resultados de uma espirometria e fornece uma avaliação básica.

    Attributes:
        fe_v1 (float): Volume Expiratório Forçado no Primeiro Segundo (em litros).
        cvf (float): Capacidade Vital Forçada (em litros).
        sexo (str): Sexo da pessoa ('masculino' ou 'feminino').
        idade (int): Idade da pessoa (em anos).

    Returns:
        str: Uma string indicando a avaliação básica dos resultados.
    """

    fev1_cvf_ratio = fe_v1 / cvf * 100  # Calcula a relação FEV1/CVF em porcentagem

    if fev1_cvf_ratio < 70:
        return "Possível obstrução das vias aéreas."
    elif fev1_cvf_ratio > 80:
        return "Valores normais."
    else:
        return "Possível restrição pulmonar."





def contar_leucocitos(numero_leucocitos,saida):
    """
    Conta o número de glóbulos brancos no sangue e retorna uma métrica de 0 a 25.

    Attributes:
        numero_leucocitos (float): Número de glóbulos brancos em milhares por microlitro (milhares/µL).
        saida (str): Define o tipo de saída desejada ('simple' para uma classificação simplificada).

    Returns:
        float: Métrica de 0 a 25 representando o número de glóbulos brancos.
    """

    if numero_leucocitos == 0:
        return "Taxa de leucócitos inválida"

    if saida == None:
        saida = "advanced"

    referencia_baixa = 4.0  # Milhares/µL
    referencia_media_baixa = 5.0
    referencia_media = 7.0
    referencia_media_alta = 9.0
    referencia_alta = 11.0
    referencia_muito_alta = 15.0
    referencia_extremamente_alta = 20.0
    referencia_super_alta = 25.0

    if numero_leucocitos < referencia_baixa:
        if saida == "simple":
            print("Extremamente baixa")
        return 0

    elif referencia_baixa <= numero_leucocitos < referencia_media_baixa:
        if saida == "simple":
            print("muito baixa")

        return (numero_leucocitos - referencia_baixa) / (referencia_media_baixa - referencia_baixa) * 3.125

    elif referencia_media_baixa <= numero_leucocitos < referencia_media:
        if saida == "simple":
            print("Baixa")
        return 3.125 + (
                    (numero_leucocitos - referencia_media_baixa) / (referencia_media - referencia_media_baixa)) * 3.125
    elif referencia_media <= numero_leucocitos < referencia_media_alta:
        if saida == "simple":
            print("Normal")
        return 6.25 + ((numero_leucocitos - referencia_media) / (referencia_media_alta - referencia_media)) * 3.125

    elif referencia_media_alta <= numero_leucocitos < referencia_alta:
        if saida == "simple":
            print("Alta")
        return 9.375 + ((numero_leucocitos - referencia_media_alta) / (referencia_alta - referencia_media_alta)) * 3.125

    elif referencia_alta <= numero_leucocitos < referencia_muito_alta:
        if saida == "simple":
            print("Muito Alta")
        return 12.5 + ((numero_leucocitos - referencia_alta) / (referencia_muito_alta - referencia_alta)) * 3.125

    elif referencia_muito_alta <= numero_leucocitos < referencia_extremamente_alta:
        if saida == "simple":
            print("Extremamente Alta")
        return 15.625 + ((numero_leucocitos - referencia_muito_alta) / (
                    referencia_extremamente_alta - referencia_muito_alta)) * 3.125

    else:
        return 25



def classificar_glicemia(glicemia):
    """
    Classifica a concentração de glicose no sangue (glicemia) em categorias.

    Attributes:
        glicemia (float): Concentração de glicose no sangue em mg/dL.

    Returns:
        str: Categoria da glicemia.
    """
    if glicemia < 70:
        return "Hipo glicemia (Muito baixa)"
    elif 70 <= glicemia < 100:
        return "Normal"
    elif 100 <= glicemia < 125:
        return "Pré-diabetes (Elevada)"
    else:
        return "Diabetes (Muito alta)"



def calcular_debito_urinario(volume_urina_Litro, tempo_Hora,saida):
    """
    Calcula o débito urinário e fornece uma classificação.

    Attributes:
        volume_urina (float): Volume de urina produzido em mililitros.
        tempo (float): Tempo decorrido para a produção de urina em minutos.

    Returns:
        tuple: Uma tupla contendo o débito urinário calculado em mililitros por minuto e sua classificação.
            O primeiro elemento é o débito urinário calculado.
            O segundo elemento é uma string representando a classificação do débito urinário, que pode ser:
                - 'muito baixo': se o débito urinário for menor que 0.5 ml/min,
                - 'baixo': se o débito urinário estiver entre 0.5 e 1.0 ml/min,
                - 'normal': se o débito urinário estiver entre 1.0 e 2.0 ml/min,
                - 'alto': se o débito urinário estiver entre 2.0 e 3.0 ml/min,
                - 'muito alto': se o débito urinário for maior que 3.0 ml/min.
    """

    if tempo_Hora <= 0:
        return "Tempo inválido", "Classificação indeterminada"


    if volume_urina_Litro < 0:
        return "Volume de urina inválido", "Classificação indeterminada"


    debito_urinario = volume_urina_Litro / tempo_Hora

    # Classificar a produção de urina
    if debito_urinario < 0.5:
        classificacao = "Produção de urina muito baixa"
    elif 0.5 <= debito_urinario < 1.5:
        classificacao = "Produção de urina baixa"
    elif 1.5 <= debito_urinario < 2.5:
        classificacao = "Produção de urina normal"
    else:
        classificacao = "Produção de urina muito alta"
    if saida == "simple":
        return debito_urinario, classificacao

    return debito_urinario



def calcular_tp(tempo_protrombina, saida='advanced'):
    """
    Calcula o Tempo de Protrombina (TP) e fornece uma classificação opcional.

    Attributes:
        tempo_protrombina (float): Tempo de Protrombina em segundos.
        saida (str): Tipo de saída desejado ('advanced' para detalhes completos ou 'simple' para classificação simplificada).
                     Padrão é 'advanced'.

    Returns:
        float or tuple: Resultado do TP. Se saida='simple', retorna apenas o resultado. Se saida='advanced',
                        retorna o resultado e uma classificação opcional.
    """

    # Definir faixas de referência
    referencia_normal = (11.0, 13.0)  # Normal em segundos
    referencia_baixa = 10.0
    referencia_alta = 14.0

    # Classificação do TP
    classificacao = None
    if tempo_protrombina < referencia_baixa:
        classificacao = "Muito baixo"
    elif referencia_baixa <= tempo_protrombina < referencia_normal[0]:
        classificacao = "Baixo"
    elif referencia_normal[0] <= tempo_protrombina <= referencia_normal[1]:
        classificacao = "Normal"
    elif referencia_normal[1] < tempo_protrombina < referencia_alta:
        classificacao = "Alto"
    else:
        classificacao = "Muito alto"

    # Retornar resultado conforme o tipo de saída
    if saida == 'simple':
        return classificacao
    else:
        return tempo_protrombina, classificacao






from .Ver_arterial_pression import verifica_pressão_arterial
from .verifica_imc import verifica_imc
from .calcular_tfg import calcular_tfg
from .contar_hemacias import contar_hemacias
from .contar_leucocitos import contar_leucocitos
from .contar_plaquetas import contar_plaquetas
from .calcular_fcm import calcular_fcm
from .calcular_frequencia_respiratoria import calcular_frequencia_respiratoria
from .calcular_debito_cardiaco import calcular_debito_cardiaco
from .calcular_tp import calcular_tp
from .calcular_ttpa import calcular_ttpa
from .calcular_indice_apgar import calcular_indice_apgar
from .classificar_pvc import classificar_pvc
from. classificar_glicemia import classificar_glicemia
from. classifica_saturacao_spo2 import classificar_spo2
from. calcular_debito_urinario import calcular_debito_urinario
from.classificar_espirometria import classificar_espirometria
from.classifica_capacidade_anaerobica import teste_capacidade_anaerobica
from.teste_funcao_renal import teste_funcao_renal
from.teste_funcao_hepatica import teste_funcao_hepatica
from.classifica_tireoidiana import teste_funcao_tireoidiana



def calcular_debito_cardiaco(fc, vs, saida='advanced'):
    """
       Calcula o Débito Cardíaco (DC) com base na frequência cardíaca (FC) e no volume sistólico (VS).

       Parameters:
           fc (float): Frequência cardíaca (batimentos por minuto).
           vs (float): Volume sistólico (mililitros por batimento).
           saida (str, opcional): Tipo de saída desejado ('advanced' para apenas o resultado, 'simple' para resultado e classificação).

       Returns:
           float or tuple: Débito Cardíaco (mililitros por minuto) ou (Débito Cardíaco, Classificação) dependendo da saída escolhida.
       """
    dc = fc * vs

    if saida == 'simple':
        if dc < 4000:
            classificacao = "Muito baixo"
        elif 4000 <= dc < 5000:
            classificacao = "Baixo"
        elif 5000 <= dc < 6000:
            classificacao = "Normal"
        elif 6000 <= dc < 7000:
            classificacao = "Alto"
        else:
            classificacao = "Muito alto"
        return dc, classificacao
    else:
        return dc



def classificar_pvc(pvc):
    """
    Classifica a Pressão Venosa Central (PVC) em categorias.

    Attributes:
        pvc (float): Pressão Venosa Central em mmHg.

    Returns:
        str: Categoria da PVC.
    """

    if pvc < 3:
        return "Muito baixa"
    elif 3 <= pvc <= 5:
        return "Baixa"
    elif 6 <= pvc <= 12:
        return "Normal"
    elif 13 <= pvc <= 18:
        return "Alta"
    else:
        return "Muito alta"



def calcular_ttpa(tempo_tromboplastina, saida='advanced'):
    """
    Calcula o Tempo de Tromboplastina Parcial Ativada (TTPA) e fornece uma classificação opcional.

    Attributes:
        tempo_tromboplastina (float): Tempo de Tromboplastina Parcial Ativada em segundos.
        saida (str): Tipo de saída desejado ('advanced' para detalhes completos ou 'simple' para classificação simplificada).
                     Padrão é 'advanced'.

    Returns:
        float or tuple: Resultado do TTPA. Se saida='simple', retorna apenas o resultado. Se saida='advanced',
                        retorna o resultado e uma classificação opcional.
    """

    # Definir faixas de referência
    referencia_muito_baixa = 24.0  # Muito baixo em segundos
    referencia_baixa = (24.0, 26.0)  # Baixo em segundos
    referencia_normal = (26.0, 35.0)  # Normal em segundos
    referencia_alta = (35.0, 36.0)  # Alto em segundos
    referencia_muito_alta = 36.0  # Muito alto em segundos


    classificacao = None
    if tempo_tromboplastina < referencia_muito_baixa:
        classificacao = "Muito baixo"
    elif referencia_muito_baixa <= tempo_tromboplastina < referencia_baixa[0]:
        classificacao = "Baixo"
    elif referencia_baixa[0] <= tempo_tromboplastina <= referencia_baixa[1]:
        classificacao = "Baixo"
    elif referencia_baixa[1] < tempo_tromboplastina < referencia_normal[0]:
        classificacao = "Baixo"
    elif referencia_normal[0] <= tempo_tromboplastina < referencia_normal[1]:
        classificacao = "Normal"
    elif referencia_normal[1] <= tempo_tromboplastina < referencia_alta[0]:
        classificacao = "Alto"
    elif referencia_alta[0] <= tempo_tromboplastina < referencia_alta[1]:
        classificacao = "Alto"
    else:
        classificacao = "Muito alto"


    if saida == 'simple':
        return classificacao
    else:
        return tempo_tromboplastina






def medir_pressão_arterial(sistólica, diastólica):
    """
    Classifica a pressão arterial com base nos valores da pressão sistólica e diastólica.

    Attributes:
        sistolica (int): Valor da pressão arterial sistólica.
        diastolica (int): Valor da pressão arterial diastólica.

    Returns:
        str: Classificação da pressão arterial, que pode ser 'Pressão arterial normal', 'Pressão arterial elevada', 'Pressão arterial de estágio 1' ou 'Pressão arterial de estágio 2'.
    """

    if sistólica < 120 and diastólica < 80:
        return "Pressão arterial normal"
    elif 120 <= sistólica < 130 and diastólica < 80:
        return "Pressão arterial elevada"
    elif 130 <= sistólica < 140 or 80 <= diastólica < 90:
        return "Pressão arterial de estágio 1"
    elif sistólica >= 140 or diastólica >= 90:
        return "Pressão arterial de estágio 2"

def verifica_pressão_arterial(sistólica, diastólica, sexo, idade, saida='simple'):
    """
    Verifica a pressão arterial e fornece uma classificação baseada nos valores da pressão sistólica e diastólica, sexo e idade.

    Attributes:
        sistolica (int): Valor da pressão arterial sistólica.
        diastolica (int): Valor da pressão arterial diastólica.
        sexo (str): Sexo da pessoa ('masculino' ou 'feminino').
        idade (int): Idade da pessoa em anos.
        saida (str): Tipo de saída desejado ('simple' para apenas o valor da classificação ou 'advanced' para a descrição completa).

    Returns:
        str or float: Se 'saida' for 'simple', retorna a classificação da pressão arterial (muito baixa, baixa, normal, elevada, estágio 1 ou estágio 2).
                      Se 'saida' for 'advanced', retorna o valor da classificação de acordo com a faixa de referência.
    """

    if sexo.lower() == 'masculino':
        idade_referência = 45
        if idade < idade_referência:
            if sistólica < 120 and diastólica < 80:
                if saida == 'simple':
                    return 12.5
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 120 <= sistólica < 130 and diastólica < 80:
                if saida == 'simple':
                    return 15
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 130 <= sistólica < 140 or 80 <= diastólica < 90:
                if saida == 'simple':
                    return 18
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif sistólica >= 140 or diastólica >= 90:
                if saida == 'simple':
                    return 25
                else:
                    return medir_pressão_arterial(sistólica,diastólica)

        else:
            if sistólica < 120 and diastólica < 80:
                if saida == 'simple':
                    return 12.5
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 120 <= sistólica < 130 and diastólica < 80:
                if saida == 'simple':
                    return 15
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 130 <= sistólica < 140 or 80 <= diastólica < 90:
                if saida == 'simple':
                    return 18
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif sistólica >= 140 or diastólica >= 90:
                if saida == 'simple':
                    return 25
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
    elif sexo.lower() == 'feminino':
        idade_referência = 55
        if idade < idade_referência:
            if sistólica < 120 and diastólica < 80:
                if saida == 'simple':
                    return 12.5
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 120 <= sistólica < 130 and diastólica < 80:
                if saida == 'simple':
                    return 15
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 130 <= sistólica < 140 or 80 <= diastólica < 90:
                if saida == 'simple':
                    return 18
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif sistólica >= 140 or diastólica >= 90:
                if saida == 'simple':
                    return 25
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
        else:
            if sistólica < 120 and diastólica < 80:
                if saida == 'simple':
                    return 12.5
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 120 <= sistólica < 130 and diastólica < 80:
                if saida == 'simple':
                    return 15
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif 130 <= sistólica < 140 or 80 <= diastólica < 90:
                if saida == 'simple':
                    return 18
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
            elif sistólica >= 140 or diastólica >= 90:
                if saida == 'simple':
                    return 25
                else:
                    return medir_pressão_arterial(sistólica,diastólica)
    else:
        return "Sexo não reconhecido"



def calcular_fcm(idade, sexo):
    """
    Calcula a Frequência Cardíaca Máxima (FCM) com base na idade e sexo.

    Attributes:
        idade (int): Idade da pessoa.
        sexo (str): Sexo da pessoa, pode ser 'masculino' ou 'feminino'.

    Returns:
        tuple: Uma tupla contendo a Frequência Cardíaca Máxima (FCM) e sua categoria de intensidade.
            O primeiro elemento é a Frequência Cardíaca Máxima (FCM) calculada.
            O segundo elemento é uma string representando a categoria de intensidade, que pode ser:
                - 'muito baixa': se a FCM estiver abaixo de 50% da FCM máxima esperada para a idade,
                - 'baixa': se a FCM estiver entre 50% e 60% da FCM máxima esperada para a idade,
                - 'normal': se a FCM estiver entre 60% e 70% da FCM máxima esperada para a idade,
                - 'alta': se a FCM estiver entre 70% e 80% da FCM máxima esperada para a idade,
                - 'muito alta': se a FCM estiver acima de 80% da FCM máxima esperada para a idade.
    """
    fcm = 220 - idade
    if sexo.lower() == 'masculino':
        referencia_muito_baixa = 0.5 * fcm
        referencia_baixa = 0.65 * fcm
        referencia_normal = 0.85 * fcm
        referencia_alta = 1.0 * fcm
        referencia_muito_alta = 1.15 * fcm
    elif sexo.lower() == 'feminino':
        referencia_muito_baixa = 0.55 * fcm
        referencia_baixa = 0.7 * fcm
        referencia_normal = 0.9 * fcm
        referencia_alta = 1.05 * fcm
        referencia_muito_alta = 1.2 * fcm
    else:
        return "Sexo não reconhecido"

    if fcm < referencia_muito_baixa:
        return fcm
    elif referencia_muito_baixa <= fcm < referencia_baixa:
        return fcm
    elif referencia_baixa <= fcm < referencia_normal:
        return fcm
    elif referencia_normal <= fcm < referencia_alta:
        return fcm
    elif referencia_alta <= fcm < referencia_muito_alta:
        return fcm
    else:
        return fcm, "Valores extremamente altos para a idade"



def verifica_imc(peso, altura, sexo, saida):
    """
    Calcula o Índice de Massa Corporal (IMC).

    Attributes:
        peso (float): Peso da pessoa em quilogramas (kg).
        altura (float): Altura da pessoa em metros (m).
        sexo (str): Sexo da pessoa ('masculino' ou 'feminino').
        saida (str): Tipo de saída desejado ('simple' ou outro valor para saída avançada).

    Returns:
        float or dict: Valor do IMC calculado. Se 'saida' for 'simple', retorna apenas o valor do IMC.
                       Se 'saida' for outro valor, retorna um dicionário com o IMC e uma classificação do estado de peso.
    """

    if saida == "simple":
        if sexo.lower() == 'masculino':
            imc = peso / (altura ** 2)
            if altura == 1.50:
                imcf = int(imc)
                if 22 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 29:
                    return "sobrepeso"
                elif 30 <= imcf <= 39:
                    return "obesidade"
                elif 40 <= imcf <= 53:
                    return "obesidade morbida"
                else:
                    return "peso invalido"
            elif altura == 1.60:
                imcf = int(imc)
                if 24 <= imcf <= 26:
                    return "normal"
                elif 27 <= imcf <= 31:
                    return "sobrepeso"
                elif 32 <= imcf <= 41:
                    return "obesidade"
                elif 42 <= imcf <= 56:
                    return "obesidade morbida"
                else:
                    return "peso invalido"
            elif altura == 1.70:
                imcf = int(imc)
                if 27 <= imcf <= 29:
                    return "normal"
                elif 30 <= imcf <= 34:
                    return "sobrepeso"
                elif 35 <= imcf <= 44:
                    return "obesidade"
                elif 45 <= imcf <= 60:
                    return "obesidade morbida"
                else:
                    return "peso invalido"


            elif altura == 1.80:
                imcf = int(imc)
                if 20 <= imcf <= 23:
                    return "normal"
                elif 24 <= imcf <= 30:
                    return "sobrepeso"
                elif 31 <= imcf <= 37:
                    return "obesidade"
                elif 38 <= imcf <= 64:
                    return "obesidade morbida"
                else:
                    return "peso invalido"

            elif altura == 1.90:
                imcf = int(imc)
                if 21 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 29:
                    return "sobrepeso"
                elif 30 <= imcf <= 33:
                    return "obesidade"
                elif 34 <= imcf <= 68:
                    return "obesidade morbida"
                else:
                    return "peso invalido"

            elif altura == 2.00:
                imcf = int(imc)
                if 20 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 29:
                    return "sobrepeso"
                elif 30 <= imcf <= 33:
                    return "obesidade"
                elif 34 <= imcf <= 72:
                    return "obesidade morbida"
                else:
                    return "peso invalido"

            elif altura == 2.10:
                imcf = int(imc)
                if 20 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 27:
                    return "sobrepeso"
                elif 28 <= imcf <= 35:
                    return "obesidade"
                elif 36 <= imcf <= 75:
                    return "obesidade morbida"
                else:
                    return "peso invalido"
            else:
                return "altura não suportada"


        elif sexo.lower() == 'feminino':
            imc = peso / ((altura - 0.4) ** 2)
            if altura == 1.50:
                imcf = int(imc)
                if 22 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 29:
                    return "sobrepeso"
                elif 30 <= imcf <= 39:
                    return "obesidade"
                elif 40 <= imcf <= 53:
                    return "obesidade morbida"
                else:
                    return "peso invalido"
            elif altura == 1.60:
                imcf = int(imc)
                if 24 <= imcf <= 26:
                    return "normal"
                elif 27 <= imcf <= 31:
                    return "sobrepeso"
                elif 32 <= imcf <= 41:
                    return "obesidade"
                elif 42 <= imcf <= 56:
                    return "obesidade morbida"
                else:
                    return "peso invalido"
            elif altura == 1.70:
                imcf = int(imc)
                if 27 <= imcf <= 29:
                    return "normal"
                elif 30 <= imcf <= 34:
                    return "sobrepeso"
                elif 35 <= imcf <= 44:
                    return "obesidade"
                elif 45 <= imcf <= 60:
                    return "obesidade morbida"
                else:
                    return "peso invalido"


            elif altura == 1.80:
                imcf = int(imc)
                if 20 <= imcf <= 23:
                    return "normal"
                elif 24 <= imcf <= 30:
                    return "sobrepeso"
                elif 31 <= imcf <= 37:
                    return "obesidade"
                elif 38 <= imcf <= 64:
                    return "obesidade morbida"
                else:
                    return "peso invalido"

            elif altura == 1.90:
                imcf = int(imc)
                if 21 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 29:
                    return "sobrepeso"
                elif 30 <= imcf <= 33:
                    return "obesidade"
                elif 34 <= imcf <= 68:
                    return "obesidade morbida"
                else:
                    return "peso invalido"

            elif altura == 2.00:
                imcf = int(imc)
                if 20 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 29:
                    return "sobrepeso"
                elif 30 <= imcf <= 33:
                    return "obesidade"
                elif 34 <= imcf <= 72:
                    return "obesidade morbida"
                else:
                    return "peso invalido"

            elif altura == 2.10:
                imcf = int(imc)
                if 20 <= imcf <= 24:
                    return "normal"
                elif 25 <= imcf <= 27:
                    return "sobrepeso"
                elif 28 <= imcf <= 35:
                    return "obesidade"
                elif 36 <= imcf <= 75:
                    return "obesidade morbida"
                else:
                    return "peso invalido"
            else:
                return "altura não suportada"

    else:
        if sexo.lower() == 'masculino':
            imc = peso / (altura ** 2)
        elif sexo.lower() == 'feminino':
            imc = peso / ((altura - 0.4) ** 2)
        else:
            return "Sexo não reconhecido"

        return imc



def teste_capacidade_anaerobica(tempo_em_minutos):
    """
    Avalia a capacidade anaeróbica com base no tempo de realização do teste de correr 1 km.

    Attributes:
        tempo_em_minutos (float): Tempo em minutos que a pessoa levou para realizar o teste.

    Returns:
        str: Classificação do desempenho (muito baixo, baixo, normal, alto, muito alto).
    """

    if tempo_em_minutos < 8:
        return "Excelente"
    elif 8 <= tempo_em_minutos < 10:
        return "Bom"
    elif 10 <= tempo_em_minutos < 12:
        return "normal"
    elif 12 <= tempo_em_minutos < 14:
        return "Lento"
    else:
        return "Muito Lento"




def calcular_tfg(creatinina_serica, idade, sexo='masculino', raca='não negra', output='ml/min/1.73m^2'):
    """
    Calcula a Taxa de Filtração Glomerular (TFG) utilizando a fórmula do MDRD.

    Attributes:
        creatinina_serica (float): Valor da creatinina sérica em mg/dL.
        idade (int): Idade do paciente em anos.
        sexo (str): Sexo do paciente ('masculino' ou 'feminino'). Padrão é masculino.
        raca (str): Raça do paciente ('negra' ou 'não negra'). Padrão é não negra.
        output (str): Tipo de saída desejado ('ml/min/1.73m^2' ou 'ml/min'). Padrão é ml/min/1.73m^2.

    Returns:
        float: Valor da TFG calculada.
    """

    if sexo.lower() == 'feminino':
        fator_sexo = 0.742
    else:
        fator_sexo = 1

    if raca.lower() == 'negra':
        fator_raca = 1.212
    else:
        fator_raca = 1


    tfg = 175 * (creatinina_serica ** (-1.154)) * (idade ** (-0.203)) * fator_sexo * fator_raca


    if output == 'ml/min':
        return tfg
    elif output == 'ml/min/1.73m^2':

        superficie_corporal = 1.73  # Média para adultos
        tfg_corrigida = tfg * superficie_corporal
        return tfg_corrigida
    else:
        return "Opção de saída inválida"






def teste_funcao_renal(creatinina, ureia, saida):
    """
    Avalia a saúde dos rins com base nos níveis de creatinina e ureia no sangue.

    Attributes:
        creatinina (float): Nível de creatinina no sangue em mg/dL.
        ureia (float): Nível de ureia no sangue em mg/dL.
        saida (str): Tipo de saída desejado ('advanced' para detalhado ou 'simple' para resumido).

    Returns:
        dict or str: Se 'saida' for 'advanced', retorna um dicionário com os resultados detalhados.
                     Se 'saida' for 'simple', retorna uma classificação simplificada da função renal.
    """

    limite_superior_creatinina = 1.2  # mg/dL
    limite_superior_ureia = 40  # mg/dL


    if creatinina <= limite_superior_creatinina and ureia <= limite_superior_ureia:
        if saida == 'simple':
            return {'resultado': 'Normal', 'detalhes': 'A função renal está dentro dos limites normais.'}
        elif saida == 'advanced':
            return 'Normal'
    elif creatinina > limite_superior_creatinina or ureia > limite_superior_ureia:
        if saida == 'simple':
            return {'resultado': 'Anormal', 'detalhes': 'A função renal está alterada. Consulte um médico.'}
        elif saida == 'advanced':
            return 'Anormal'



def classificar_apgar(nota):
    """
    Classifica a nota do Índice de Apgar em termos de saúde do recém-nascido.

    Attributes:
        nota (int): Nota de 0 a 5 referente a um aspecto do Índice de Apgar.

    Returns:
        str: Classificação da nota em termos de saúde do recém-nascido.
    """
    if nota <= 1:
        return "muito baixa"
    elif 1 < nota <= 3:
        return "baixa"
    elif 3 < nota <= 4:
        return "aceitável"
    else:
        return "ótimo"


def calcular_indice_apgar(cor, frequencia_cardiaca, respiracao, tonus_muscular, reflexos,saida):
    """
    Calcula o Índice de Apgar com base nos critérios fornecidos.

    Attributes:
        cor (int): Nota de 0 a 5 referente à cor da pele.
        frequencia_cardiaca (int): Nota de 0 a 5 referente à frequência cardíaca.
        respiracao (int): Nota de 0 a 5 referente à respiração.
        tonus_muscular (int): Nota de 0 a 5 referente ao tônus muscular.
        reflexos (int): Nota de 0 a 5 referente aos reflexos.

    Returns:
        int: Índice de Apgar total, representando a saúde do recém-nascido no momento do nascimento.
    """
    cor = min(cor, 5)
    frequencia_cardiaca = min(frequencia_cardiaca, 5)
    respiracao = min(respiracao, 5)
    tonus_muscular = min(tonus_muscular, 5)
    reflexos = min(reflexos, 5)

    indice_apgar = (cor + frequencia_cardiaca + respiracao + tonus_muscular + reflexos) / 5
    if saida == "simple":
        return classificar_apgar(indice_apgar)

    else:
        return indice_apgar



def contar_plaquetas(numero_plaquetas,saida):
    """
    Conta o número de plaquetas no sangue e retorna uma métrica de 0 a 25.

    Attributes:
        numero_plaquetas (float): Número de plaquetas por microlitro (por μL).
        saida (str): Indica o tipo de saída desejada ('simple' para uma classificação simplificada).

    Returns:
        float: Métrica de 0 a 25 representando o número de plaquetas.
    """

    referencia_muito_baixa = 50000  # por μL
    referencia_baixa = 150000
    referencia_normal = 450000
    referencia_alta = 750000
    referencia_muito_alta = 1000000

    if numero_plaquetas == 0:
        return "Numero de plaquetas invalido"


    if numero_plaquetas < referencia_muito_baixa:
        if saida == "simple":
            print( "extremamente baixa")
        return 0
    elif referencia_muito_baixa <= numero_plaquetas < referencia_baixa:
        if saida == "simple":
            print( "Muito baixa")
        return (numero_plaquetas - referencia_muito_baixa) / (referencia_baixa - referencia_muito_baixa) * 6.25
    elif referencia_baixa <= numero_plaquetas < referencia_normal:
        if saida == "simple":
            print ("Baixa")
        return 6.25 + ((numero_plaquetas - referencia_baixa) / (referencia_normal - referencia_baixa)) * 6.25
    elif referencia_normal <= numero_plaquetas < referencia_alta:
        if saida == "simple":
            print( "Alta")
        return 12.5 + ((numero_plaquetas - referencia_normal) / (referencia_alta - referencia_normal)) * 14.25
    elif referencia_alta <= numero_plaquetas < referencia_muito_alta:
        if saida == "simple":
             print("Muito Alta")
        return 18.75 + ((numero_plaquetas - referencia_alta) / (referencia_muito_alta - referencia_alta)) * 6.25
    else:
        if saida == "simple":
            print( "extremamente Alta")
            return 25



def classificar_spo2(spo2):
    """
    Classifica a saturação de oxigênio (SpO2) em categorias.

    Attributes:
        spo2 (float): Saturação de oxigênio em porcentagem (%).

    Returns:
        str: Categoria da saturação de oxigênio.
    """

    if spo2 < 90:
        return "Baixa saturação de oxigênio"
    elif 90 <= spo2 < 95:
        return "Saturação de oxigênio normal baixa"
    elif 95 <= spo2 <= 100:
        return "Saturação de oxigênio normal"
    else:
        return "Valor inválido"



def teste_funcao_hepatica(ast, alt, alp, bilirrubina_total, bilirrubina_direta, bilirrubina_indireta, saida='advanced'):
    """
    Avalia a saúde do fígado com base nos níveis de enzimas hepáticas e bilirrubina no sangue.

    Attributes:
        ast (float): Nível da enzima AST (aspartato aminotransferase) no sangue em U/L.
        alt (float): Nível da enzima ALT (alanina aminotransferase) no sangue em U/L.
        alp (float): Nível da enzima ALP (fosfatase alcalina) no sangue em U/L.
        bilirrubina_total (float): Nível total de bilirrubina no sangue em mg/dL.
        bilirrubina_direta (float): Nível de bilirrubina direta no sangue em mg/dL.
        bilirrubina_indireta (float): Nível de bilirrubina indireta no sangue em mg/dL.
        saida (str): Tipo de saída desejado ('advanced' para detalhado ou 'simple' para resumido).

    Returns:
        dict or str: Se 'saida' for 'advanced', retorna um dicionário com os resultados detalhados.
                     Se 'saida' for 'simple', retorna uma classificação simplificada da função hepática.
    """

    # Definir os limites de referência para as enzimas hepáticas e bilirrubina
    limite_superior_ast = 40  # U/L
    limite_superior_alt = 56  # U/L
    limite_superior_alp = 120  # U/L
    limite_superior_bilirrubina_total = 1.2  # mg/dL
    limite_superior_bilirrubina_direta = 0.3  # mg/dL
    limite_superior_bilirrubina_indireta = 0.9  # mg/dL

    if (ast <= limite_superior_ast and alt <= limite_superior_alt and alp <= limite_superior_alp and
            bilirrubina_total <= limite_superior_bilirrubina_total and
            bilirrubina_direta <= limite_superior_bilirrubina_direta and
            bilirrubina_indireta <= limite_superior_bilirrubina_indireta):
        if saida == 'advanced':
            return {'resultado': 'Normal', 'detalhes': 'A função hepática está dentro dos limites normais.'}
        elif saida == 'simple':
            return 'Normal'
    else:
        if saida == 'advanced':
            return {'resultado': 'Anormal', 'detalhes': 'A função hepática está alterada. Consulte um médico.'}
        elif saida == 'simple':
            return 'Anormal'



def contar_hemacias(numero_hemacias, sexo,saida):
    """
    Conta o número de hemácias no sangue e retorna uma métrica de 0 a 25.

    Attributes:
        numero_hemacias (float): Número de hemácias em milhões por microlitro (milhões/μL).
        sexo (str): Sexo da pessoa ('masculino' ou 'feminino').

    Returns:
        float: Métrica de 0 a 25 representando o número de hemácias.
    """

    # Definir faixas de referência
    referencia_muito_baixa_homens = 4.5  # Milhões/µL
    referencia_baixa_homens = 5.5
    referencia_normal_homens = 6.5
    referencia_alta_homens = 7.5
    referencia_muito_alta_homens = 10.0

    referencia_muito_baixa_mulheres = 4.0  # Milhões/µL
    referencia_baixa_mulheres = 5.0
    referencia_normal_mulheres = 6.0
    referencia_alta_mulheres = 7.0
    referencia_muito_alta_mulheres = 10.0

    if sexo.lower() == 'masculino':
        if numero_hemacias == 0:
            return "Contagem de hemacias invalida"
        elif numero_hemacias < referencia_muito_baixa_homens:
            if saida == "simple":
                print("Muito baixa")
            return 3
        elif referencia_muito_baixa_homens <= numero_hemacias < referencia_baixa_homens:
            if saida == "simple":
                print("Baixa")
            return (numero_hemacias - referencia_muito_baixa_homens) / (
                        referencia_baixa_homens - referencia_muito_baixa_homens) * 6.25
        elif referencia_baixa_homens <= numero_hemacias < referencia_normal_homens:
            if saida == "simple":
                print("Normal")
            return 6.25 + ((numero_hemacias - referencia_baixa_homens) / (
                        referencia_normal_homens - referencia_baixa_homens)) * 6.25
        elif referencia_normal_homens <= numero_hemacias < referencia_alta_homens:
            if saida == "simple":
                print("Alta")
            return 12.5 + ((numero_hemacias - referencia_normal_homens) / (
                        referencia_alta_homens - referencia_normal_homens)) * 6.25
        elif referencia_alta_homens <= numero_hemacias < referencia_muito_alta_homens:
            if saida == "simple":
                print("Muito Alta")
            return 18.75 + ((numero_hemacias - referencia_alta_homens) / (
                        referencia_muito_alta_homens - referencia_alta_homens)) * 6.25
    elif sexo.lower() == 'feminino':

        if numero_hemacias < referencia_muito_baixa_mulheres:
            if saida == "simple":
                print("Muito baixa")
            return 0
        elif referencia_muito_baixa_mulheres <= numero_hemacias < referencia_baixa_mulheres:
            if saida == "simple":
                print("Baixa")
            return (numero_hemacias - referencia_muito_baixa_mulheres) / (
                        referencia_baixa_mulheres - referencia_muito_baixa_mulheres) * 6.25
        elif referencia_baixa_mulheres <= numero_hemacias < referencia_normal_mulheres:
            if saida == "simple":
                print("Normal")
            return 6.25 + ((numero_hemacias - referencia_baixa_mulheres) / (
                        referencia_normal_mulheres - referencia_baixa_mulheres)) * 6.25
        elif referencia_normal_mulheres <= numero_hemacias < referencia_alta_mulheres:
            if saida == "simple":
                print("Alta")
            return 12.5 + ((numero_hemacias - referencia_normal_mulheres) / (
                        referencia_alta_mulheres - referencia_normal_mulheres)) * 6.25
        elif referencia_alta_mulheres <= numero_hemacias < referencia_muito_alta_mulheres:
            if saida == "simple":
                print("Muito Alta")
            return 18.75 + ((numero_hemacias - referencia_alta_mulheres) / (
                        referencia_muito_alta_mulheres - referencia_alta_mulheres)) * 6.25
    else:
        return "Sexo não reconhecido"
